==> azure_ml_component-0.1.0.29596699-py3-none-any.whl: azure/ml/component/_execution/_constants.py <==
# ---------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ---------------------------------------------------------
SLEEP_INTERVAL = 5
MODULE_PROPERTY_NAME = 'azureml.moduleid'
MOCK_PARALLEL_DRIVER = '_mock_parallel_driver.py'

# File/folder name
OUTPUT_DIR_NAME = 'outputs'
IMAGE_DIR_NAME = 'image_logs'
CONDA_DIR_NAME = 'conda_logs'
SCRIPTE_DIR_NAME = 'scripts'
EXECUTION_LOGFILE = 'excutionlogs.txt'

# Input/output/script path in container
CONTAINER_INPUT_PATH = '/mnt/input'
CONTAINER_OUTPUT_PATH = '/mnt/{}'.format(OUTPUT_DIR_NAME)
CONTAINER_MOUNT_SCRIPTS_PATH = '/mnt/scripts'

# Prefix of component run log
RUN_PREPARE_LOG = 'Run prepare stage'
RUN_EXEC_LOG = 'Run execute stage'
RUN_RELEASE_LOG = 'Run release stage'
USER_ERROR_MSG = 'Executing script failed with a non-zero exit code; see the %s for details.'

# Component run status
PREPAREING = 'Preparing'
RUNNING = 'Running'
COMPLETED = 'Completed'
FAILED = 'Failed'

RUN_STATUS = {
    'NotStarted': '0',
    'Preparing': '3',
    'Running': '5',
    'Completed': '8',
    'Failed': '9'
}
STATUS_CODE = {
    'NotStarted': '0',
    'Preparing': '2',
    'Running': '3',
    'Failed': '4',
    'Completed': '5',
}

# Keyword of visualizer
PARENT_NODE_ID = '@parent'
NODE_LOG_KEY = '70_driver_log.txt'
PARENT_LOG_KEY = 'logs/azureml/executionlogs.txt'

# Step status info of visualizer
STEP_STATUS = {
    'runStatus': None,
    'startTime': None,
    'endTime': None,
    'status': None,
    'statusCode': None,
    'statusDetail': None,
    'runDetailsUrl': None
}

# Pipeline run keyword
NODE_ID = 'node_id'
STEP_PREFIX = 'prefix'
WORKING_DIR = 'working_dir'
RUN_ID = 'run_id'

==> azure_ml_component-0.1.0.31098150-py3-none-any.whl: azure/ml/component/_execution/_constants.py <==
# ---------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ---------------------------------------------------------
SLEEP_INTERVAL = 5
MODULE_PROPERTY_NAME = 'azureml.moduleid'
MOCK_PARALLEL_DRIVER = '_mock_parallel_driver.py'

# File/folder name
OUTPUT_DIR_NAME = 'outputs'
IMAGE_DIR_NAME = 'image_logs'
CONDA_DIR_NAME = 'conda_logs'
SCRIPTE_DIR_NAME = 'scripts'
EXECUTION_LOGFILE = 'excutionlogs.txt'

# Input/output/script path in container
LINUX_CONTAINER_INPUT_PATH = '/mnt/input'
LINUX_CONTAINER_OUTPUT_PATH = '/mnt/{}'.format(OUTPUT_DIR_NAME)
LINUX_CONTAINER_MOUNT_SCRIPTS_PATH = '/mnt/scripts'

WINDOWS_CONTAINER_INPUT_PATH = 'c:\\input'
WINDOWS_CONTAINER_OUTPUT_PATH = 'c:\\{}'.format(OUTPUT_DIR_NAME)
WINDOWS_CONTAINER_MOUNT_SCRIPTS_PATH = 'c:\\scripts'

# Prefix of component run log
RUN_PREPARE_LOG = 'Run prepare stage'
RUN_EXEC_LOG = 'Run execute stage'
RUN_RELEASE_LOG = 'Run release stage'
USER_ERROR_MSG = 'Executing script failed with a non-zero exit code; see the %s for details.'

# Component run status
PREPAREING = 'Preparing'
RUNNING = 'Running'
COMPLETED = 'Completed'
FAILED = 'Failed'

RUN_STATUS = {
    'NotStarted': '0',
    'Preparing': '3',
    'Running': '5',
    'Completed': '8',
    'Failed': '9'
}
STATUS_CODE = {
    'NotStarted': '0',
    'Preparing': '2',
    'Running': '3',
    'Failed': '4',
    'Completed': '5',
}

# Keyword of visualizer
PARENT_NODE_ID = '@parent'
NODE_LOG_KEY = '70_driver_log.txt'
PARENT_LOG_KEY = 'logs/azureml/executionlogs.txt'

# Step status info of visualizer
STEP_STATUS = {
    'runStatus': None,
    'startTime': None,
    'endTime': None,
    'status': None,
    'statusCode': None,
    'statusDetail': None,
    'runDetailsUrl': None
}

# Pipeline run keyword
NODE_ID = 'node_id'
STEP_PREFIX = 'prefix'
WORKING_DIR = 'working_dir'
RUN_ID = 'run_id'

# It's a flag for CommandExecution to test execution environment is wsl/container.
# If it in os.environ, CommandExecution will think current environment is wsl/container.
TEST_COMMAND_EXECUTE_IN_WSL_OR_CONTAINER = 'test_in_wsl_or_container'
